@@ -3,7 +3,7 @@
 import os
 import fnmatch
 
-def all_file(root, patterns='*.pyc', ignore_dirs={}, \
+def all_file(root, patterns='*.pyc', ignore_dirs=[], \
         single_level=False, logger=None, no_matchs=False):
     """
     root:            需要遍历的目录
@@ -11,15 +11,12 @@ def all_file(root, patterns='*.pyc', ignore_dirs={}, \
     single_level:    是否只遍历单层目录，默认为否
     """
     patterns = tuple([p.strip() for p in patterns.split(',')])
-    ignore_dir = ''
+    ignore_dirs = set(ignore_dirs)
     for path, subdirs, files in os.walk(root):
-        if ignore_dir and path.startswith(ignore_dir):
-            log('ignore subdir %s' % path, logger)
-            continue
-        if ignore_dirs.get(os.path.basename(path), None):
-            log('ignore dir %s' % path, logger)
-            ignore_dir = path
-            continue
+        has_ignore_dirs = set(subdirs) & ignore_dirs
+        if has_ignore_dirs:
+            for d in has_ignore_dirs:
+                subdirs.remove(d)
         for pattern in patterns:
             fs = fnmatch.filter(files, pattern)
             if not fs:
@@ -38,8 +35,9 @@ def log(msg, logger=None):
 
 def clean(args, logger=None, no_matchs=False):
     filter = args.filter
+    ignore_dirs = []
     if args.ignore_dirs:
-        ignore_dirs = dict([(d.strip(), 1) for d in args.ignore_dirs.split(',') if d])
+        ignore_dirs = args.ignore_dirs.split(',')
     path = args.path
     for f in all_file(path, filter, ignore_dirs, logger=logger, \
             no_matchs=no_matchs):
@@ -51,7 +49,6 @@ def clean(args, logger=None, no_matchs=False):
 
 def main():
     import gc
-    import time
     from argparse import ArgumentParser
     parser = ArgumentParser(description='Clean your files.')
     parser.add_argument('path', default='.', nargs='?',
